pyparsing.pyparsing.OnlyOnce

Package pyparsing :: Module pyparsing :: Class OnlyOnce |
[hide private]
[frames] | no frames]

# Class OnlyOnce

source code

    object --+
             |
            OnlyOnce

Wrapper for parse actions, to ensure they are only called once.

Instance Methods | [hide private]
__init__(self, methodCall) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
__call__(self, s, l, t) | source code
reset(self) | source code
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, methodCall) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)